@@ -693,31 +693,12 @@ sub keybinder {
             return;
         }
         if ($key eq "s") {
-            {
-                my $wstat = $widget->{'stat'}->width;
-                my $textl = "Accounting System (AS) - save data and continue editing";
-                my $textr = "F1 Help";
-                my $textf = " " x ($wstat -2 -length($textl) -1 -1 -length($textr) - 2) . " ";
-                my $text  = sprintf("  %s %s %s ", $textl, $textf, $textr);
-                $widget->{'info'}->{-text} = $text;
-                $widget->{'info'}->draw;
-            }
+            &statusline("save data and continue editing");
             $breakout = 1;
             return;
         }
         elsif ($key eq "q") {
-            if ($cui->dialog(-message => " Quit without saving? \n" .
-                                         " Changes will be lost ",
-                                           -buttons => 
-                                           [
-                                                { -label => "[ OK ]",     -value => 1 },
-                                                { -label => "[ Cancel ]", -value => 0 }
-                                           ]
-                                            )
-                ) {
-                $widget->{"dummy"}->focus;
-                $breakout = 2;
-            }
+            $breakout = 2 if (&commonquit());
             return;
         }
         elsif ($key eq "x" or $key eq "Z") {
@@ -764,32 +745,18 @@ sub keybinder {
         $matrixwidget->{"VC.$vc.$vr"}->{-canvasscr}->attroff(A_STANDOUT);
         $matrixwidget->{"VC.$vc.$vr"}->draw;
         $widget->{"dummy"}->focus;
-        {
-            my $wstat = $widget->{'stat'}->width;
-            my $textl = "Accounting System (AS) - save data and continue editing";
-            my $textr = "F1 Help";
-            my $textf = " " x ($wstat -2 -length($textl) -1 -1 -length($textr) - 2) . " ";
-            my $text  = sprintf("  %s %s %s ", $textl, $textf, $textr);
-            $widget->{'info'}->{-text} = $text;
-            $widget->{'info'}->draw;
-        }
+        &statusline("save data and continue editing");
         $breakout = 1;
         return;
     }
     elsif ($key eq "q") {
         $matrixwidget->{"VC.$vc.$vr"}->{-canvasscr}->attroff(A_STANDOUT);
         $matrixwidget->{"VC.$vc.$vr"}->draw;
-        if ($cui->dialog(-message => " Quit without saving? \n" .
-                                     " Changes will be lost ",
-                                       -buttons => 
-                                       [
-                                            { -label => "[ OK ]",     -value => 1 },
-                                            { -label => "[ Cancel ]", -value => 0 }
-                                       ]
-                                        )
-            ) {
-            $widget->{"dummy"}->focus;
-            $breakout = 2;
+        if (&commonquit()) {
+            $breakout = 2
+        }
+        else {
+            $datacoll = 1;
         }
         return;
     }
@@ -856,7 +823,34 @@ sub keybinder {
         $vr = $nvr;
         $vc = $nvc;
     }
-    elsif ($key eq "^" or $key eq "0") {
+    elsif ($key eq "0") {
+        my $newdc = undef;
+        my $c;
+        #   search jump destination begin of columns to current cell
+        for ($c = 0; $c < $matrixdata->{"Columns"}; $c++) {
+            if ($matrixdata->{"CH.$c"}->{"Coljump"} and not $matrixdata->{"CH.$c"}->{"Colhide"}) {
+                $newdc = $c;
+                last;
+            }
+        }
+        return unless(defined $newdc); #do not change focus if no jump destination found
+        my $deltadc = $newdc - $dc;
+        my $stepdir = $deltadc < 0 ? -1 : +1;
+        my $deltavc = 0;
+        for ($c = $dc; $c != $newdc; $c += $stepdir) {
+            $deltavc += $stepdir if (not $matrixdata->{"CH.$c"}->{"Colhide"});
+        }
+        $vc += $deltavc;
+        if ($vc < 0) {
+            $vcscroll = $vc;
+            $vc = 0;
+        }
+        if ($vc > 0) {
+            $vcscroll = $vc;
+            $vc = 0;
+        }
+    }
+    elsif ($key eq "^") {
         $vc = 0;
         $vcpos = -1;
     }
@@ -896,7 +890,7 @@ sub keybinder {
         unless (defined $newdc) {
             #   search jump destination from next cell to the end of the columns
             for ($c = $dc + 1; $c < $matrixdata->{"Columns"}; $c++) {
-                if ($matrixdata->{"CH.$c"}->{"Coljump"}) {
+                if ($matrixdata->{"CH.$c"}->{"Coljump"} and not $matrixdata->{"CH.$c"}->{"Colhide"}) {
                     $newdc = $c;
                     last;
                 }
@@ -910,15 +904,20 @@ sub keybinder {
             }
             #   search jump destination begin of columns to current cell
             for ($c = 0; $c < $dc; $c++) {
-                if ($matrixdata->{"CH.$c"}->{"Coljump"}) {
+                if ($matrixdata->{"CH.$c"}->{"Coljump"} and not $matrixdata->{"CH.$c"}->{"Colhide"}) {
                     $newdc = $c;
                     last;
                 }
             }
         }
         return unless(defined $newdc); #do not change focus if no jump destination found
-        my $deltac = $newdc - $dc;
-        $vc += $deltac;
+        my $deltadc = $newdc - $dc;
+        my $stepdir = $deltadc < 0 ? -1 : +1;
+        my $deltavc = 0;
+        for ($c = $dc; $c != $newdc; $c += $stepdir) {
+            $deltavc += $stepdir if (not $matrixdata->{"CH.$c"}->{"Colhide"});
+        }
+        $vc += $deltavc;
         if ($vc < 0) {
             $vcscroll = $vc;
             $vc = 0;
@@ -934,7 +933,7 @@ sub keybinder {
         unless (defined $newdc) {
             #   search jump destination from previous cell to the begin of the columns
             for ($c = $dc - 1; $c >= 0; $c--) {
-                if ($matrixdata->{"CH.$c"}->{"Coljump"}) {
+                if ($matrixdata->{"CH.$c"}->{"Coljump"} and not $matrixdata->{"CH.$c"}->{"Colhide"}) {
                     $newdc = $c;
                     last;
                 }
@@ -948,15 +947,20 @@ sub keybinder {
             }
             #   search jump destination end of columns to current cell
             for ($c = $matrixdata->{"Columns"}; $c > $dc; $c--) {
-                if ($matrixdata->{"CH.$c"}->{"Coljump"}) {
+                if ($matrixdata->{"CH.$c"}->{"Coljump"} and not $matrixdata->{"CH.$c"}->{"Colhide"}) {
                     $newdc = $c;
                     last;
                 }
             }
         }
         return unless(defined $newdc); #do not change focus if no jump destination found
-        my $deltac = $newdc - $dc;
-        $vc += $deltac;
+        my $deltadc = $newdc - $dc;
+        my $stepdir = $deltadc < 0 ? -1 : +1;
+        my $deltavc = 0;
+        for ($c = $dc; $c != $newdc; $c += $stepdir) {
+            $deltavc += $stepdir if (not $matrixdata->{"CH.$c"}->{"Colhide"});
+        }
+        $vc += $deltavc;
         if ($vc < 0) {
             $vcscroll = $vc;
             $vc = 0;
@@ -1309,6 +1313,22 @@ sub keybinder {
     }
 }
 
+sub commonquit() {
+    my $rc = 0;
+    if (    not $matrixdata->{"dirty"} 
+         or $cui->dialog(-message => " Quit without saving? \n" .
+                                     " Changes will be lost ",
+                         -buttons => [
+                                          { -label => "[ OK ]",     -value => 1 },
+                                          { -label => "[ Cancel ]", -value => 0 }
+                                     ])
+           ) {
+        $rc = 1;
+    }
+    $widget->{"dummy"}->focus;
+    return $rc;
+}
+
 sub destroymatrixwidgetcells {
     foreach my $i (sort keys %{$matrixwidget}) {
         if ($i =~ m/^VC\.\d+\.\d+/ || $i =~ m/^(CH|RH)\.(\d+|fill.*)/) {
@@ -1354,6 +1374,24 @@ sub drawfocusmatrixwidget {
     }
 }
 
+sub statusline() {
+    my ($textl, $textr) = (@_);
+    my $wstat = $widget->{'stat'}->width;
+    if (not defined $textl or $textl eq "") {
+        $textl = "";
+        $textl .= "[+] " if ($matrixdata->{"dirty"});
+        $textl .= "ESC=Menu; F1=Help";
+    }
+    if (not defined $textr or $textr eq "") {
+        $textr = "Accounting System (" . $matrixdata->{"progname"} . " " . $matrixdata->{"progvers"} . ")";
+    }
+    my $textf = " " x ($wstat -2 -length($textl) -1 -1 -length($textr) - 2);
+    my $text  = sprintf("  %s %s %s  ", $textl, $textf, $textr);
+    $widget->{'info'}->{-text} = $text;
+    $widget->{'info'}->draw;
+    $widget->{'dummy'}->draw if (defined $widget->{'dummy'}); # cursor stay away!
+}
+
 sub ascuinew {
      ($matrixdata, $verbose) = (@_);
 
@@ -1377,7 +1415,18 @@ sub ascuinew {
 
     #   create menu widget
     my $menu_file = [
-        { -label => 'Quit program',       -value => sub {exit(0)}        },
+        { -label => 'Quit',
+          -value =>
+            sub {
+                if (&commonquit()) {
+                    $breakout = 2
+                }
+                else {
+                    $datacoll = 1;
+                }
+                $widget->{'dummy'}->focus;
+            }
+        }
     ];
     my $menu_as = [
         { -label => 'Testerli 1',         -value => sub {exit(0)}        },
@@ -1406,16 +1455,10 @@ sub ascuinew {
     );
 
     #   add a status line
-    my $wstat = $widget->{'stat'}->width;
-    my $textl = "Accounting System (AS)";
-    my $textr = "F1 Help";
-    my $textf = " " x ($wstat -2 -length($textl) -1 -1 -length($textr) - 2) . " ";
-    my $text  = sprintf("  %s %s %s ", $textl, $textf, $textr);
-    $widget->{'status'}->{-text} = $text;
     $widget->{'info'} = $widget->{'stat'}->add('info', 'Label',
-        -text => $text,
-        -reverse => 1,
+        -reverse => 1
     );
+    &statusline();
 
     #   add a container
     $widget->{'container'} = $widget->{'main'}->add(undef, 'Container');
@@ -1434,15 +1477,6 @@ sub ascuinew {
 }
 
 sub ascuido {
-    {
-        my $wstat = $widget->{'stat'}->width;
-        my $textl = "Accounting System (AS)";
-        my $textr = "F1 Help";
-        my $textf = " " x ($wstat -2 -length($textl) -1 -1 -length($textr) - 2) . " ";
-        my $text  = sprintf("  %s %s %s ", $textl, $textf, $textr);
-        $widget->{'info'}->{-text} = $text;
-        $widget->{'info'}->draw;
-    }
     &newmatrixwidget();
     my ($upperleftcol, $cursorcol) = ($matrixdata->{"CK.date"}, 0); #&rightmostvisiblefit();
     my ($upperleftrow, $cursorrow) = &bottommostvisiblefit();
@@ -1456,6 +1490,7 @@ sub ascuido {
         $vcpos    = 0;
         $vrpos    = 0;
 
+        &statusline() unless($editcell);
         $cui->root->do_one_event;
 
         if    ($vcscroll < 0) {
